/* 
   Crystal Display Light Stand

   Utilizing a single NeoPixel driven by ESP8266 controller
      
   Measurements in millimeters
   
   Concept, Design and Implementation: Craig A. Lindley
   Last Update: 06/29/2023
*/

$fa = 1;
$fs = 0.4;

// Mirror dimensions
MIRROR_DIAMETER = 76.2; // 3"
MIRROR_THICKNESS = 1.5;

// Mirror hole diameter
MIRROR_HOLE_DIAMETER = 25.4; // 3"

// Wall thickness
WALL_THICKNESS = 2;

// Stand dimemsions
STAND_OUTSIDE_DIAMETER = MIRROR_DIAMETER + (2.0 * WALL_THICKNESS) + 0.2;
STAND_INSIDE_DIAMETER  = MIRROR_DIAMETER - (2.0 * WALL_THICKNESS);
STAND_HEIGHT = 28.5;

module stand() {
  difference() {
    // Body
    translate([0, 0, STAND_HEIGHT / 2.0]) {
      cylinder(h = STAND_HEIGHT, d = STAND_OUTSIDE_DIAMETER, center = true);  
    }
  
    // Center hole
    cylinder(h = STAND_HEIGHT * 3.0, d = MIRROR_HOLE_DIAMETER, center = true); 
    
    // Inner cutout
    translate([0, 0, (STAND_HEIGHT / 2.0) - WALL_THICKNESS]) {
      cylinder(h = STAND_HEIGHT, d = STAND_INSIDE_DIAMETER, center = true);
    }    
    
    // Shelf cutouts
    // Bottom
    cylinder(h = MIRROR_THICKNESS * 2.0, d = MIRROR_DIAMETER, center = true);
   }
}

  
 module bottom() {
   cylinder(h = MIRROR_THICKNESS, d = MIRROR_DIAMETER, center = true); 
 }
 
 stand();
 
  
// bottom();
  
  
  
  
  
