/*
  Index.html file for Crystal Light Web Page

  Concept, Design and Implementation by: Craig A. Lindley
  Last Update: 07/01/2023
*/

const char index_html[] PROGMEM = R"rawliteral(
<!DOCTYPE HTML><html>
<head>
  <title>Crystal Light</title>
  <meta name="viewport" content="width=device-width, initial-scale=1">
  <link rel="icon" href="data:,">
  <style>
  html {
    font-family: Arial, Helvetica, sans-serif;
    text-align: center;
  }
  h1 {
    font-size: 1.6rem;
    color: white;
  }
  h2 {
    font-size: 1.1rem;
//    font-weight: bold;
    color: white;
  }
  .topnav {
    overflow: hidden;
    background-color: #143642;
  }
  .bottomnav {
    overflow: hidden;
    background-color: #143642;
  }
  .bodytext {
    text-align: left;
    font-weight: light;
    border-radius: 5px;
    display:inline;
  }
  .center-horizonally {
    display: flex;
    justify-content: center;
  }
  .radiobuttons {
    text-align: left;
    font-weight: light;
  }
  </style>
</head>
<body>
  <div class="topnav">
    <h2>Crystal Light</h1>
  </div>
  <p>- Power -</p>
  <div class="center-horizonally">
    <div class="radiobuttons">
      <div>
        <input type="radio" name="power" value="1" id="power_on" checked onclick="websocket.send('PC:1')">
        <label for="power_on">On</label>
      </div>
      <div>
        <input type="radio" name="power" value="0" id="power_off" onclick="websocket.send('PC:0')">
        <label for="power_off">Off</label>
      </div>
    </div>
  </div>
  <p>- Select Mode -</p>
  <div class="center-horizonally">
    <div class="radiobuttons">
      <div>
        <input type="radio" name="mode" value="0" id="mode_swepted" checked onclick="websocket.send('MC:0')">
        <label for="mode_swepted">Swepted</label>
      </div>
      <div>
        <input type="radio" name="mode" value="1" id="mode_stepped" onclick="websocket.send('MC:1')">
        <label for="mode_stepped">Stepped</label>
      </div>
    </div>
  </div>
  <p>- Select Direction -</p>
  <div class="center-horizonally">
    <div class="radiobuttons">
      <div>
        <input type="radio" name="direction" value="0" id="dir_up" checked onclick="websocket.send('DC:0')">
        <label for="dir_up">Up</label>
      </div>
      <div>
        <input type="radio" name="direction" value="1" id="dir_updown" onclick="websocket.send('DC:1')">
        <label for="dir_updown">Up then Down</label>
      </div>
    </div>
  </div>
  <p>- Select Speed -</p>
  <div class="center-horizonally">
   <div class="radiobuttons">
      <div>
        <input type="radio" name="speed" value="0" id="speed_slow" onclick="websocket.send('SC:0')">
        <label for="speed_slow">Slow</label>
      </div>
      <div>
        <input type="radio" name="speed" value="1" id="speed_medium" checked onclick="websocket.send('SC:1')">
        <label for="speed_medium">Medium</label>
      </div>
      <div>
        <input type="radio" name="speed" value="1" id="speed_fast" onclick="websocket.send('SC:2')">
        <label for="speed_fast">Fast</label>
      </div>
    </div>
  </div>
  <br>
  <div class="bottomnav">
    <h2>Craig A. Lindley</h2>
  </div>
<script>
  var gateway = `ws://${window.location.hostname}/ws`;
  var websocket;
  window.addEventListener('load', initWebSocket());
  function initWebSocket() {
    console.log('Trying to open a WebSocket connection...');
    websocket = new WebSocket(gateway);
    websocket.onopen    = onOpen;
    websocket.onclose   = onClose;
  }
  function onOpen(event) {
    console.log('Connection opened');
  }
  function onClose(event) {
    console.log('Connection closed');
    setTimeout(initWebSocket, 2000);
  }
</script>
</body>
</html>
)rawliteral";
